@@ -193,6 +193,13 @@ static void ScalePlaneDown2_16(int src_width,
                                                  : ScaleRowDown2Box_16_NEON;
   }
 #endif
+#if defined(HAS_SCALEROWDOWN2_16_SME)
+  if (TestCpuFlag(kCpuHasSME)) {
+    ScaleRowDown2 = filtering == kFilterNone     ? ScaleRowDown2_16_SME
+                    : filtering == kFilterLinear ? ScaleRowDown2Linear_16_SME
+                                                 : ScaleRowDown2Box_16_SME;
+  }
+#endif
 #if defined(HAS_SCALEROWDOWN2_16_SSE2)
   if (TestCpuFlag(kCpuHasSSE2) && IS_ALIGNED(dst_width, 16)) {
     ScaleRowDown2 =
@@ -1166,6 +1173,11 @@ static int ScalePlaneBilinearDown(int src_width,
     }
   }
 #endif
+#if defined(HAS_INTERPOLATEROW_SME)
+  if (TestCpuFlag(kCpuHasSME)) {
+    InterpolateRow = InterpolateRow_SME;
+  }
+#endif
 #if defined(HAS_INTERPOLATEROW_MSA)
   if (TestCpuFlag(kCpuHasMSA)) {
     InterpolateRow = InterpolateRow_Any_MSA;
@@ -1305,6 +1317,11 @@ static int ScalePlaneBilinearDown_16(int src_width,
     }
   }
 #endif
+#if defined(HAS_INTERPOLATEROW_16_SME)
+  if (TestCpuFlag(kCpuHasSME)) {
+    InterpolateRow = InterpolateRow_16_SME;
+  }
+#endif
 
 #if defined(HAS_SCALEFILTERCOLS_16_SSSE3)
   if (TestCpuFlag(kCpuHasSSSE3) && src_width < 32768) {
@@ -1386,6 +1403,11 @@ static int ScalePlaneBilinearUp(int src_width,
     }
   }
 #endif
+#if defined(HAS_INTERPOLATEROW_SME)
+  if (TestCpuFlag(kCpuHasSME)) {
+    InterpolateRow = InterpolateRow_SME;
+  }
+#endif
 #if defined(HAS_INTERPOLATEROW_RVV)
   if (TestCpuFlag(kCpuHasRVV)) {
     InterpolateRow = InterpolateRow_RVV;
@@ -1886,6 +1908,11 @@ static int ScalePlaneBilinearUp_16(int src_width,
     }
   }
 #endif
+#if defined(HAS_INTERPOLATEROW_16_SME)
+  if (TestCpuFlag(kCpuHasSME)) {
+    InterpolateRow = InterpolateRow_16_SME;
+  }
+#endif
 
   if (filtering && src_width >= 32768) {
     ScaleFilterCols = ScaleFilterCols64_16_C;
@@ -2309,9 +2336,9 @@ int I420Scale(const uint8_t* src_y,
   int dst_halfheight = SUBSAMPLE(dst_height, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2354,9 +2381,9 @@ int I420Scale_16(const uint16_t* src_y,
   int dst_halfheight = SUBSAMPLE(dst_height, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2399,9 +2426,9 @@ int I420Scale_12(const uint16_t* src_y,
   int dst_halfheight = SUBSAMPLE(dst_height, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2443,9 +2470,9 @@ int I444Scale(const uint8_t* src_y,
               enum FilterMode filtering) {
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2484,9 +2511,9 @@ int I444Scale_16(const uint16_t* src_y,
                  enum FilterMode filtering) {
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2525,9 +2552,9 @@ int I444Scale_12(const uint16_t* src_y,
                  enum FilterMode filtering) {
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2571,9 +2598,9 @@ int I422Scale(const uint8_t* src_y,
   int dst_halfwidth = SUBSAMPLE(dst_width, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2614,9 +2641,9 @@ int I422Scale_16(const uint16_t* src_y,
   int dst_halfwidth = SUBSAMPLE(dst_width, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2657,9 +2684,9 @@ int I422Scale_12(const uint16_t* src_y,
   int dst_halfwidth = SUBSAMPLE(dst_width, 1, 1);
   int r;
 
-  if (!src_y || !src_u || !src_v || src_width <= 0 || src_height == 0 ||
-      src_width > 32768 || src_height > 32768 || !dst_y || !dst_u || !dst_v ||
-      dst_width <= 0 || dst_height <= 0) {
+  if (!src_y || !src_u || !src_v || src_width <= 0 ||
+      src_height == 0 || src_width > 32768 || src_height > 32768 || !dst_y ||
+      !dst_u || !dst_v || dst_width <= 0 || dst_height <= 0) {
     return -1;
   }
 
@@ -2717,6 +2744,38 @@ int NV12Scale(const uint8_t* src_y,
   return r;
 }
 
+LIBYUV_API
+int NV24Scale(const uint8_t* src_y,
+              int src_stride_y,
+              const uint8_t* src_uv,
+              int src_stride_uv,
+              int src_width,
+              int src_height,
+              uint8_t* dst_y,
+              int dst_stride_y,
+              uint8_t* dst_uv,
+              int dst_stride_uv,
+              int dst_width,
+              int dst_height,
+              enum FilterMode filtering) {
+  int r;
+
+  if (!src_y || !src_uv || src_width <= 0 || src_height == 0 ||
+      src_width > 32768 || src_height > 32768 || !dst_y || !dst_uv ||
+      dst_width <= 0 || dst_height <= 0) {
+    return -1;
+  }
+
+  r = ScalePlane(src_y, src_stride_y, src_width, src_height, dst_y,
+                 dst_stride_y, dst_width, dst_height, filtering);
+  if (r != 0) {
+    return r;
+  }
+  r = UVScale(src_uv, src_stride_uv, src_width, src_height, dst_uv,
+              dst_stride_uv, dst_width, dst_height, filtering);
+  return r;
+}
+
 // Deprecated api
 LIBYUV_API
 int Scale(const uint8_t* src_y,
